==> defi_state_querier-0.0.1-py3-none-any.whl: defi_services/services/lending/lending_info/arbitrum/radiant_arbitrum.py <==
RADIANT_ARB = {
    "address": "0xf4b1486dd74d07706052a33d31d7c0aafd0659e1",
    "name": "Radiant Lending Pool",
    "rewardToken": "0x3082cc23568ea640225c2467653db90e9250aaa0",
    "multiFeeAddress": "0x76ba3ec5f5adbf1c58c91e86502232317eea72de",
    "chefIncentiveAddress": '0xebc85d44cefb1293707b11f707bd3cec34b4d5fa',
    "oracleAddress": "0xc0ce5de939aad880b0bddcf9ab5750a53eda454b",
    "type": "LENDING_POOL",
    "reservesList": {
        "0x2f2a2543b76a4166549f7aab2e75bef0aefc5b0f": {
            "tToken": "0x727354712bdfcd8596a3852fd2065b3c34f4f770",
            "dToken": "0x3eeafa33625df20837ed0cb83ae4d1e34788b141",
            "sdToken": "0x9ee73b7dd519f89168592ef97b29c97d844befb0",
            "liquidationThreshold": 0.75
        },
        "0xfd086bc7cd5c481dcc9c85ebe478a1c0b69fcbb9": {
            "tToken": "0xd69d402d1bdb9a2b8c3d88d98b9ceaf9e4cd72d9",
            "dToken": "0x7c2e0f792ea5b4a4dbd7fa7f949cf39a5c0ba185",
            "sdToken": "0xc6277b25076770dd408979346b81d0373e9bba5a",
            "liquidationThreshold": 0.85
        },
        "0xff970a61a04b1ca14834a43f5de4533ebddb5cc8": {
            "tToken": "0x48a29e756cc1c097388f3b2f3b570ed270423b3d",
            "dToken": "0x107583adaa37dfd1cc0bf577183bf91351d07413",
            "sdToken": "0x21f01f6bc5f6d8fa2dcf67b9ff2c163211874951",
            "liquidationThreshold": 0.85
        },
        "0xda10009cbd5d07dd0cecc66161fc93d7c9000da1": {
            "tToken": "0x0d914606f3424804fa1bbbe56ccc3416733acec6",
            "dToken": "0x04a8faed05c97290ab4d793a971adee97cd1cbbd",
            "sdToken": "0xd085657fc2e2046463e9c918a30d5f29114e7958",
            "liquidationThreshold": 0.85
        },
        "0x82af49447d8a07e3bd95bd0d56f35241523fbab1": {
            "tToken": "0x0df5dfd95966753f01cb80e76dc20ea958238c46",
            "dToken": "0xab04c0841f39596c9f18a981a2bd32f63ab7a817",
            "sdToken": "0xfe91b5a00506944ae9d09fd6249ea0363cd88809",
            "liquidationThreshold": 0.825
        },
        "0x5979d7b546e38e414f7e9822514be443a4800529": {
            "tToken": "0x42c248d137512907048021b30d9da17f48b5b7b2",
            "dToken": "0x97b81aa985115953ba31d59781e2d8159a50f488",
            "sdToken": "0xc8598d86d4f829cab345f619e5db12042dd5f73e",
            "liquidationThreshold": 0.8
        },
        "0x912ce59144191c1204e64559fe8253a0e49e6548": {
            "tToken": "0x2dade5b7df9da3a7e1c9748d169cd6dff77e3d01",
            "dToken": "0x295b97012945bd4a1a79ec7f679e16761a437e5c",
            "sdToken": "0xbf0d23fb0b471415f0b332780e69a0c019399a34",
            "liquidationThreshold": 0.5
        }
    }
}

==> defi_state_querier-0.4.22-py3-none-any.whl: defi_services/services/lending/lending_info/arbitrum/radiant_arbitrum.py <==
RADIANT_ARB = {
    "address": "0xf4b1486dd74d07706052a33d31d7c0aafd0659e1",
    "name": "Radiant Lending Pool",
    "rewardToken": "0x3082cc23568ea640225c2467653db90e9250aaa0",
    "multiFeeAddress": "0x76ba3ec5f5adbf1c58c91e86502232317eea72de",
    "stakedIncentiveAddress": '0xebc85d44cefb1293707b11f707bd3cec34b4d5fa',
    "oracleAddress": "0xc0ce5de939aad880b0bddcf9ab5750a53eda454b",
    "type": "LENDING_POOL",
    "forked": "aave-v2",
    "reservesList": {
        "0x2f2a2543b76a4166549f7aab2e75bef0aefc5b0f": {
            "tToken": "0x727354712bdfcd8596a3852fd2065b3c34f4f770",
            "dToken": "0x3eeafa33625df20837ed0cb83ae4d1e34788b141",
            "sdToken": "0x9ee73b7dd519f89168592ef97b29c97d844befb0",
            "liquidationThreshold": 0.75
        },
        "0xfd086bc7cd5c481dcc9c85ebe478a1c0b69fcbb9": {
            "tToken": "0xd69d402d1bdb9a2b8c3d88d98b9ceaf9e4cd72d9",
            "dToken": "0x7c2e0f792ea5b4a4dbd7fa7f949cf39a5c0ba185",
            "sdToken": "0xc6277b25076770dd408979346b81d0373e9bba5a",
            "liquidationThreshold": 0.85
        },
        "0xff970a61a04b1ca14834a43f5de4533ebddb5cc8": {
            "tToken": "0x48a29e756cc1c097388f3b2f3b570ed270423b3d",
            "dToken": "0x107583adaa37dfd1cc0bf577183bf91351d07413",
            "sdToken": "0x21f01f6bc5f6d8fa2dcf67b9ff2c163211874951",
            "liquidationThreshold": 0.85
        },
        "0xda10009cbd5d07dd0cecc66161fc93d7c9000da1": {
            "tToken": "0x0d914606f3424804fa1bbbe56ccc3416733acec6",
            "dToken": "0x04a8faed05c97290ab4d793a971adee97cd1cbbd",
            "sdToken": "0xd085657fc2e2046463e9c918a30d5f29114e7958",
            "liquidationThreshold": 0.85
        },
        "0x82af49447d8a07e3bd95bd0d56f35241523fbab1": {
            "tToken": "0x0df5dfd95966753f01cb80e76dc20ea958238c46",
            "dToken": "0xab04c0841f39596c9f18a981a2bd32f63ab7a817",
            "sdToken": "0xfe91b5a00506944ae9d09fd6249ea0363cd88809",
            "liquidationThreshold": 0.825
        },
        "0x5979d7b546e38e414f7e9822514be443a4800529": {
            "tToken": "0x42c248d137512907048021b30d9da17f48b5b7b2",
            "dToken": "0x97b81aa985115953ba31d59781e2d8159a50f488",
            "sdToken": "0xc8598d86d4f829cab345f619e5db12042dd5f73e",
            "liquidationThreshold": 0.8
        },
        "0x912ce59144191c1204e64559fe8253a0e49e6548": {
            "tToken": "0x2dade5b7df9da3a7e1c9748d169cd6dff77e3d01",
            "dToken": "0x295b97012945bd4a1a79ec7f679e16761a437e5c",
            "sdToken": "0xbf0d23fb0b471415f0b332780e69a0c019399a34",
            "liquidationThreshold": 0.5
        }
    }
}
